=================
Python Wave Runup
=================


.. image:: https://img.shields.io/pypi/v/py_wave_runup.svg
        :target: https://pypi.python.org/pypi/py_wave_runup

.. image:: https://img.shields.io/travis/com/chrisleaman/py-wave-runup.svg
        :target: https://travis-ci.com/chrisleaman/py-wave-runup

.. image:: https://readthedocs.org/projects/py-wave-runup/badge/?version=latest
    :target: https://py-wave-runup.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status


.. image:: https://pyup.io/repos/github/chrisleaman/py-wave-runup/shield.svg
     :target: https://pyup.io/repos/github/chrisleaman/py-wave-runup/
     :alt: Updates

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black

Empirical wave runup models implemented in Python


* Free software: GNU General Public License v3
* Documentation: https://py-wave-runup.readthedocs.io.


Features
--------

* TODO
